#!/bin/bash
#
# Copyright (c) 2002 on behalf of the EU DataGrid Project: 
# The European Organization for Nuclear Research (CERN).
# Particle Physics and Astronomy Research Council (PPARC).
# All rights reserved.
# see LICENSE file for details
#
# Author  Tuomas Nissi <tuomas.nissi@hip.fi>
#
# Creates the necessary directories and files during the
# the install process and sets necessary cron jobs
#
# Package  : edg-java-security
# Release  : 1.5.11
# Changelog:
#
#=================================================================

#############################################################################
#
# The directory /edg/var/etc/<service>/<vo> is created and necessary
# congiguration files are created under that directory.
#
#  -v VO       -- to specify the VO name (mandatory)
#  -s Service  -- to specify the service name (mandatory)
#  -q          -- supress error messages (e.g. if you like your init.d quiet)
#
# The script will look for the configuration file in 
# ${EDG_LOCATION_VAR}/etc/
# with the Service and VO as specified by the arguments you give to the script. 
# This config file defines:
#
# WHAT ARE NECESSARY???
#
# POLICY_XML_TEMPLATE  -- The templae file for the policy.xml
# VALUES_FILE          -- Values to be replaced to the template
# CRONJOB_DIR          -- The directory where to place the cronjob files
#
# VALUES file:
# @WSDL.SUBSERVICE@
#
##############################################################################


#####################################
# Options you might like to change. #
#####################################


################################################################
# Things below this here, you probably *don't* want to change. #
################################################################

# The function to fetch EDG enfironment

#
# This bash function sets up the Edg environment
#

function edg-env-func(){

    # The location of the standard EDG environment setup
    EDG_ENV=/etc/sysconfig/edg
    EDG_ENV_HOME=$HOME/.etc.sysconfig.edg
    
    #save the existing settings
    EDG_LOCATION_SAVE=$EDG_LOCATION
    EDG_LOCATION_VAR_SAVE=$EDG_LOCATION_VAR
    EDG_TMP_SAVE=$EDG_TMP
    X509_USER_CERT_SAVE=$X509_USER_CERT
    X509_USER_KEY_SAVE=$X509_USER_KEY
    GRIDMAP_SAVE=$GRIDMAP
    GRIDMAPDIR_SAVE=$GRIDMAPDIR


    # The location of the standard globus environment setup
    GLOBUS_ENV=/etc/sysconfig/globus

    # And the standard Globus environment
    if [ -r ${GLOBUS_ENV} ]; then
        source ${GLOBUS_ENV}
    fi

    # Check for Globus location, and set default if necessary
    if [ "x${GLOBUS_LOCATION}x" = xx ]; then
        GLOBUS_LOCATION=/opt/globus
    fi

    # Add the Globus libs to the default shared library path
    if [ x${LD_LIBRARY_PATH}x = xx ]; then
        export LD_LIBRARY_PATH=${GLOBUS_LOCATION}/lib:/usr/lib;
    else
        export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${GLOBUS_LOCATION}/lib:/usr/lib;
    fi


    # first use the system defaults
    if [ -r $EDG_ENV ] ; then
        source $EDG_ENV
    fi
    
    # then override with values from $HOME dir
    if [ -r $EDG_ENV_HOME ] ; then
        source $EDG_ENV_HOME
    fi

    # use values that were possibly set before script was run or the defaults if not set
    if [ "x${EDG_LOCATION_SAVE}x" != xx ]; then
        EDG_LOCATION=$EDG_LOCATION_SAVE
    else
        if [ "x${EDG_LOCATION}x" = xx ]; then
            echo Warning: EDG_LOCATION not set, neither is the system default set, using default /opt/edg
            EDG_LOCATION=/opt/edg
#        else
#            echo Warning: EDG_LOCATION not set, using system default ${EDG_LOCATION}
        fi
    fi

    if [ "x${EDG_LOCATION_VAR_SAVE}x" != xx ]; then
        EDG_LOCATION_VAR=$EDG_LOCATION_VAR_SAVE
    else
        if [ "x${EDG_LOCATION_VAR}x" = xx ]; then
            echo Warning: EDG_LOCATION_VAR not set, neither is the system default set, using default /opt/edg/var
            EDG_LOCATION_VAR=/opt/edg/var
#        else
#            echo Warning: EDG_LOCATION_VAR not set, using system default ${EDG_LOCATION_VAR}
        fi
    fi

    if [ "x${EDG_TMP_SAVE}x" != xx ]; then
        EDG_TMP=$EDG_TMP_SAVE
    else
        if [ "x${EDG_TMP}x" = xx ]; then
            echo Warning: EDG_TMP not set, neither is the system default set, using default /tmp
            EDG_TMP=/tmp
#        else
#            echo Warning: EDG_TMP not set, using system default ${EDG_TMP}
        fi
    fi

    if [ "x${X509_USER_CERT_SAVE}x" != xx ]; then
        X509_USER_CERT=$X509_USER_CERT_SAVE
    else
        if [ "x${X509_USER_CERT}x" = xx ]; then
#            echo Warning: X509_USER_CERT not set, neither is the system default set, using default /etc/grid-security/hostcert.pem
            X509_USER_CERT=/etc/grid-security/hostcert.pem
#        else
#            echo Warning: X509_USER_CERT not set, using system default ${X509_USER_CERT}
        fi
    fi

    if [ "x${X509_USER_KEY_SAVE}x" != xx ]; then
        X509_USER_KEY=$X509_USER_KEY_SAVE
    else
        if [ "x${X509_USER_KEY}x" = xx ]; then
#            echo Warning: X509_USER_KEY not set, neither is the system default set, using default /etc/grid-security/hostkey.pem
            X509_USER_KEY=/etc/grid-security/hostkey.pem
#        else
#            echo Warning: X509_USER_KEY not set, using system default ${X509_USER_KEY}
        fi
    fi

    if [ "x${GRIDMAP_SAVE}x" != xx ]; then
        GRIDMAP=$GRIDMAP_SAVE
    else
        if [ "x${GRIDMAP}x" = xx ]; then
#            echo Warning: GRIDMAP not set, neither is the system default set, using default /etc/grid-security/grid-mapfile
            GRIDMAP=/etc/grid-security/grid-mapfile
#        else
#            echo Warning: GRIDMAP not set, using system default ${GRIDMAP}
        fi
    fi

    if [ "x${GRIDMAPDIR_SAVE}x" != xx ]; then
        GRIDMAPDIR=$GRIDMAPDIR_SAVE
    else
        if [ "x${GRIDMAPDIR}x" = xx ]; then
#            echo Warning: GRIDMAPDIR not set, neither is the system default set, using default /etc/grid-security/gridmapdir
            GRIDMAPDIR=/etc/grid-security/gridmapdir
#        else
#            echo Warning: GRIDMAPDIR not set, using system default ${GRIDMAPDIR}
        fi
    fi

}

# The location of the standard EDG envirnoment setup
#EDG_ENV=/etc/sysconfig/edg

# Pasre the options to get the service name, 
# VO and the quiet flag
QUIET=normal
VO=unspecified
SERVICE=unspecified
while getopts "qv:s:" Option
do
  case $Option in
      q) QUIET=quiet ;;
      v) VO=$OPTARG ;; 
      s) SERVICE=$OPTARG ;;
      *) exit 1 ;;
  esac
done

if [ ${VO} = unspecified ]; then
    [ ${QUIET} != quiet ] && echo "Unspecified VO, defaulting to 'genericvo'"
    VO=genericvo
fi

if [ ${SERVICE} = unspecified ]; then
    [ ${QUIET} != quiet ] && echo "Unspecified service, defaulting to generic 'genericservice'"
    SERVICE=genericservice
fi

# Get the EDG envirnoment
edg-env-func

# Set the name of the directory where the configuration
# will be stored.
SERVICE_CONFIG_DIR=${EDG_LOCATION_VAR}/etc/${SERVICE}/${VO}

# make the directory
if [ ! -d ${SERVICE_CONFIG_DIR} ]; then
    mkdir -p ${SERVICE_CONFIG_DIR} || 
    { 
	echo Error: the ${SERVICE_CONFIG_DIR} directory creation failed; 
	exit 2; 
    }
fi

# read configuration
if [ -r ${SERVICE_CONFIG_DIR} ]; then
    . $SERVICE_CONFIG_DIR}/service.conf
else
    echo Error: cannot read $SERVICE_CONFIG_DIR}/service.conf;
    exit 2;
fi

# create policy.xml file from the template
if [ -r ${POLICY_XML_TEMPLATE} && -r ${VALUESFILE} ]; then

# ${EDG_LOCATION}/sbin/edg-template-conf.pl does the replacing.. 

    ${EDG_LOCATION}/sbin/edg-template-conf.pl ${POLICY_XML_TEMPLATE} \
	${VALUESFILE} ${SERVIC_CONFIG_DIR} ||
    {
	echo Error the service block creation failed; 
	exit 2;
    }
else
    echo ${POLICY_XML_TEMPLATE} or ${VALUESFILE} is not readable;
    exit 2;
fi


# TODO: moving scripts and other files to correct places

# move the script to the correct directory. If the directory
# is not specified in the service.conf file the default 
# ${EDG_LOCATION}/etc/cron/ is used

if [ x${CRONJOB_DIR}x = xx ]

    mv ${ }med-authz-update-cron ${CRONJOB_DIR}/ ||
    {
	echo Error: could not move the med-authz-update-cron to the ${CRONJOB_DIR} directory; 
	exit 2;
    }
    
else
    mv ${ }med-authz-update-cron ${EDG_LOCATION}/etc/cron/ || 
	{
	    echo Error: could not move the med-authz-update-cron to the ${EDG_LOCATION}/etc/cron/ directory; 
	    exit 2;
    }

fi











