#!/bin/bash
#
# Copyright (c) 2002 on behalf of the EU DataGrid Project: 
# The European Organization for Nuclear Research (CERN).
# Particle Physics and Astronomy Research Council (PPARC).
# All rights reserved.
# see LICENSE file for details
#
# Author  Tuomas Nissi <tuomas.nissi@hip.fi>
#
# (Re)load the configuration files and generate
# a new gridmap file from the. 
#
# Package  : edg-java-security
# Release  : 1.5.11     
# Changelog:
#
#=================================================================

#############################################################################
#
# Command line parameters: 
#
#  -v VO       -- to specify the VO name (mandatory)
#  -s Service  -- to specify the service name (mandatory)
#  -q          -- supress error messages (e.g. if you like your init.d quiet)
#
# The script will look for the configuration file in 
# ${EDG_LOCATION_VAR}/etc/<service>/<vo>/conf/<service>-<vo>.conf
# with the Service and VO as specified by the arguments you give to the script. 
#
# WHAT DEFINES?
#
# This config file defines:
#
# MKGRIDMAP_CONF_LOCATION     -- Location from which to load the mkgridmap.conf
# TRANSALATION_CONF_LOCATION  -- Location from which to load the translation.conf
#
# The files are loaded to the ${EDG_LOCATION_VAR}/etc/<service>/<vo> directory 
# and the new gridmap file is created there. Possibly existing files are 
# overwritten. 
#
# filenames mkgridmap.conf, translation.conf and gridmap
#
##############################################################################


#####################################
# Options you might like to change. #
#####################################

#default values from where to load the files with wget
DEFAULT_MKGRIDMAP_CONF_LOCATION=dunno.org
DEFAULT_TRANSLATION_CONF_LOCATION=dunno.org

################################################################
# Things below this here, you probably *don't* want to change. #
################################################################

# function to fetch EDG environment

#
# This bash function sets up the Edg environment
#

function edg-env-func(){

    # The location of the standard EDG environment setup
    EDG_ENV=/etc/sysconfig/edg
    EDG_ENV_HOME=$HOME/.etc.sysconfig.edg
    
    #save the existing settings
    EDG_LOCATION_SAVE=$EDG_LOCATION
    EDG_LOCATION_VAR_SAVE=$EDG_LOCATION_VAR
    EDG_TMP_SAVE=$EDG_TMP
    X509_USER_CERT_SAVE=$X509_USER_CERT
    X509_USER_KEY_SAVE=$X509_USER_KEY
    GRIDMAP_SAVE=$GRIDMAP
    GRIDMAPDIR_SAVE=$GRIDMAPDIR


    # The location of the standard globus environment setup
    GLOBUS_ENV=/etc/sysconfig/globus

    # And the standard Globus environment
    if [ -r ${GLOBUS_ENV} ]; then
        source ${GLOBUS_ENV}
    fi

    # Check for Globus location, and set default if necessary
    if [ "x${GLOBUS_LOCATION}x" = xx ]; then
        GLOBUS_LOCATION=/opt/globus
    fi

    # Add the Globus libs to the default shared library path
    if [ x${LD_LIBRARY_PATH}x = xx ]; then
        export LD_LIBRARY_PATH=${GLOBUS_LOCATION}/lib:/usr/lib;
    else
        export LD_LIBRARY_PATH=${LD_LIBRARY_PATH}:${GLOBUS_LOCATION}/lib:/usr/lib;
    fi


    # first use the system defaults
    if [ -r $EDG_ENV ] ; then
        source $EDG_ENV
    fi
    
    # then override with values from $HOME dir
    if [ -r $EDG_ENV_HOME ] ; then
        source $EDG_ENV_HOME
    fi

    # use values that were possibly set before script was run or the defaults if not set
    if [ "x${EDG_LOCATION_SAVE}x" != xx ]; then
        EDG_LOCATION=$EDG_LOCATION_SAVE
    else
        if [ "x${EDG_LOCATION}x" = xx ]; then
            echo Warning: EDG_LOCATION not set, neither is the system default set, using default /opt/edg
            EDG_LOCATION=/opt/edg
#        else
#            echo Warning: EDG_LOCATION not set, using system default ${EDG_LOCATION}
        fi
    fi

    if [ "x${EDG_LOCATION_VAR_SAVE}x" != xx ]; then
        EDG_LOCATION_VAR=$EDG_LOCATION_VAR_SAVE
    else
        if [ "x${EDG_LOCATION_VAR}x" = xx ]; then
            echo Warning: EDG_LOCATION_VAR not set, neither is the system default set, using default /opt/edg/var
            EDG_LOCATION_VAR=/opt/edg/var
#        else
#            echo Warning: EDG_LOCATION_VAR not set, using system default ${EDG_LOCATION_VAR}
        fi
    fi

    if [ "x${EDG_TMP_SAVE}x" != xx ]; then
        EDG_TMP=$EDG_TMP_SAVE
    else
        if [ "x${EDG_TMP}x" = xx ]; then
            echo Warning: EDG_TMP not set, neither is the system default set, using default /tmp
            EDG_TMP=/tmp
#        else
#            echo Warning: EDG_TMP not set, using system default ${EDG_TMP}
        fi
    fi

    if [ "x${X509_USER_CERT_SAVE}x" != xx ]; then
        X509_USER_CERT=$X509_USER_CERT_SAVE
    else
        if [ "x${X509_USER_CERT}x" = xx ]; then
#            echo Warning: X509_USER_CERT not set, neither is the system default set, using default /etc/grid-security/hostcert.pem
            X509_USER_CERT=/etc/grid-security/hostcert.pem
#        else
#            echo Warning: X509_USER_CERT not set, using system default ${X509_USER_CERT}
        fi
    fi

    if [ "x${X509_USER_KEY_SAVE}x" != xx ]; then
        X509_USER_KEY=$X509_USER_KEY_SAVE
    else
        if [ "x${X509_USER_KEY}x" = xx ]; then
#            echo Warning: X509_USER_KEY not set, neither is the system default set, using default /etc/grid-security/hostkey.pem
            X509_USER_KEY=/etc/grid-security/hostkey.pem
#        else
#            echo Warning: X509_USER_KEY not set, using system default ${X509_USER_KEY}
        fi
    fi

    if [ "x${GRIDMAP_SAVE}x" != xx ]; then
        GRIDMAP=$GRIDMAP_SAVE
    else
        if [ "x${GRIDMAP}x" = xx ]; then
#            echo Warning: GRIDMAP not set, neither is the system default set, using default /etc/grid-security/grid-mapfile
            GRIDMAP=/etc/grid-security/grid-mapfile
#        else
#            echo Warning: GRIDMAP not set, using system default ${GRIDMAP}
        fi
    fi

    if [ "x${GRIDMAPDIR_SAVE}x" != xx ]; then
        GRIDMAPDIR=$GRIDMAPDIR_SAVE
    else
        if [ "x${GRIDMAPDIR}x" = xx ]; then
#            echo Warning: GRIDMAPDIR not set, neither is the system default set, using default /etc/grid-security/gridmapdir
            GRIDMAPDIR=/etc/grid-security/gridmapdir
#        else
#            echo Warning: GRIDMAPDIR not set, using system default ${GRIDMAPDIR}
        fi
    fi

}

# The location of the standard EDG envirnoment setup
#EDG_ENV=/etc/sysconfig/edg

MKGRIDMAP_CONF_LOCATION=
TRANSLATION_CONF_LOCATION=

# Pasre the options to get the service name, 
# VO and the quiet flag
QUIET=normal
VO=unspecified
SERVICE=unspecified
while getopts "qv:s:" Option
do
  case $Option in
      q) QUIET=quiet ;;
      v) VO=$OPTARG ;; 
      s) SERVICE=$OPTARG ;;
      *) exit 1 ;;
  esac
done

if [ ${VO} = unspecified ]; then
    [ ${QUIET} != quiet ] && echo "Unspecified VO, defaulting to 'genericvo'"
    VO=genericvo
fi

if [ ${SERVICE} = unspecified ]; then
    [ ${QUIET} != quiet ] && echo "Unspecified service, defaulting to generic 'genericservice'"
    SERVICE=genericservice
fi

# Get the EDG envirnoment
edg-env-func

# Get the name of the directory where the configuration
# will be stored.
SERVICE_CONFIG_DIR=${EDG_LOCATION_VAR}/etc/${SERVICE}/${VO}

# Load locations from which to load the files.
if [ -r ${SERVICE_CONFIG_DIR}/service.conf ]; then
    . ${SERVICE_CONFIG_DIR}/service.conf
fi

# If the file does not exist the defaults defined 
# in the beginning of this script will be used.
if [ "x${MKGRIDMAP_CONF_LOCATION}x" = xx ]; then
    [ ${QUIET} != quiet ] && echo MKGRIDPMAP_CONF_LOCATION not defined, using default: ${DEFAULT_MKGRIDMAP_CONF_LOCATION}
    MKGRIDMAP_CONF_LOCATION=${DEFAULT_MKGRIDMAP_CONF_LOCATION}
fi

if [ "x${TRANSLATION_CONF_LOCATION}x" = xx ]; then
    [ ${QUIET} != quiet ] && echo TRANSLATION_CONF_LOCATION not defined, using default: ${DEFAULT_TRANSLATION_CONF_LOCATION}
    TRANSLATION_CONF_LOCATION=${DEFAULT_TRANSLATION_CONF_LOCATION}
fi

# Load the files. Overwrites existing files if any. 
if [ ${QUIET} = "quiet" ]; then
    { wget -q --output-document=${SERVICE_CONFIG_DIR}/mkgridmap.conf \
	    ${MKGRIDMAP_CONF_LOCATION} > /dev/null 2>&1; } || 
	    { echo Error: failed to load the file from ${MKGRIDMAP_CONF_LOCATION}; 
	    exit 2; }
    wget -q --output-document=${SERVICE_CONFIG_DIR}/translation.conf \
	    ${TRANSLATION_CONF_LOCATION} > /dev/null 2>&1 || 
	    { echo Error: failed to load the file from ${TRANSLATION_CONF_LOCATION}; 
	    exit 2;}
else
    wget --output-document=${SERVICE_CONFIG_DIR}/mkgridmap.conf \
	${MKGRIDMAP_CONF_LOCATION} || { echo Error: failed to load the file \
	from ${MKGRIDMAP_CONF_LOCATION}; exit 2; }
    wget --output-document=${SERVICE_CONFIG_DIR}/translation.conf \
	${TRANSLATION_CONF_LOCATION} || { echo Error: failed to load the file \
	from ${TRANSLATION_CONF_LOCATION}; exit 2; }
fi

# generating the gridmap
if [ ${QUIET} = "quiet" ]; then 
    { ${EDG_LOCATION}/sbin/mkgridmap --config=${SERVICE_CONFIG_DIR}/mkgridmap.conf \
	--output=${SERVICE_CONFIG_DIR}/gridmap  /dev/null 2>&1 } ||
	{ echo Error: generating gridmap failed; exit 2; }
else
    { ${EDG_LOCATION}/sbin/mkgridmap --config=${SERVICE_CONFIG_DIR}/mkgridmap.conf \
	--output=${SERVICE_CONFIG_DIR}/gridmap --verbose } ||
	{ echo Error: generating gridmap failed; exit 2; }

fi












